@@ -4,7 +4,7 @@ similarities within a corpus of documents.
 """
 
 # for IPython tab-completion
-import utils, matutils, interfaces, corpora, models, similarities
+from gensim import utils, matutils, interfaces, corpora, models, similarities
 import logging
 
 
