@@ -19,6 +19,7 @@ from __future__ import with_statement
 
 import logging
 import itertools
+import UserDict
 
 from gensim import utils
 from gensim._six import iteritems, iterkeys, itervalues, string_types
@@ -29,7 +30,7 @@ from gensim._six.moves import zip as izip
 logger = logging.getLogger('gensim.corpora.dictionary')
 
 
-class Dictionary(utils.SaveLoad, dict):
+class Dictionary(utils.SaveLoad, UserDict.DictMixin):
     """
     Dictionary encapsulates the mapping between normalized words and their integer ids.
 
@@ -238,7 +239,7 @@ class Dictionary(utils.SaveLoad, dict):
         Note: use `save`/`load` to store in binary format instead (pickle).
         """
         logger.info("saving dictionary mapping to %s" % fname)
-        with utils.smart_open(fname, 'wb') as fout:
+        with utils.smart_open(fname, 'w') as fout:
             for token, tokenid in sorted(iteritems(self.token2id)):
                 fout.write("%i\t%s\t%i\n" % (tokenid, token, self.dfs.get(tokenid, 0)))
 
@@ -336,6 +337,7 @@ class Dictionary(utils.SaveLoad, dict):
         # now make sure length(result) == get_max_id(corpus) + 1
         for i in xrange(max_id + 1):
             result.token2id[str(i)] = i
+            result.dfs[i] = result.dfs.get(i, 0)
 
         logger.info("built %s from %i documents (total %i corpus positions)" %
                      (result, result.num_docs, result.num_pos))
