@@ -36,11 +36,12 @@ The algorithm:
 
 from __future__ import with_statement
 
-import logging, itertools, time
+import logging, time
 import numpy as np
 import scipy.special as sp
 
 from gensim import interfaces, utils
+from gensim._six.moves import xrange
 
 logger = logging.getLogger(__name__)
 
@@ -137,9 +138,10 @@ class HdpModel(interfaces.TransformationABC):
     >>> hdp = HdpModel(corpus, id2word)
     >>> hdp.print_topics(topics=20, topn=10)
 
-    The model doesn't support inference of topics on new, unseen documents, yet.
+    Inference on new documents is based on the approximately LDA-equivalent topics.
 
     Model persistency is achieved through its `load`/`save` methods.
+
     """
     def __init__(self, corpus, id2word, max_chunks=None, max_time=None,
                  chunksize=256, kappa=1.0, tau=64.0, K=15, T=150, alpha=1,
@@ -165,8 +167,13 @@ class HdpModel(interfaces.TransformationABC):
         self.max_time = max_time
         self.outputdir = outputdir
 
+        self.lda_alpha = None
+        self.lda_beta = None
+
         self.m_W = len(id2word)
-        self.m_D = len(corpus)
+        self.m_D = 0
+        if corpus:
+          self.m_D = len(corpus)
 
         self.m_T = T
         self.m_K = K
@@ -202,6 +209,31 @@ class HdpModel(interfaces.TransformationABC):
         if corpus is not None:
             self.update(corpus)
 
+    def inference(self, chunk):
+        if self.lda_alpha is None or self.lda_beta is None:
+            raise RuntimeError("model must be trained to perform inference")
+        chunk = list(chunk)
+        if len(chunk) > 1:
+            logger.debug("performing inference on a chunk of %i documents" % len(chunk))
+
+        gamma = np.zeros((len(chunk), self.lda_beta.shape[0]))
+        for d, doc in enumerate(chunk):
+            if not doc:  # leave gamma at zero for empty documents
+                continue
+            ids, counts = zip(*doc)
+            _, gammad = lda_e_step(ids, counts, self.lda_alpha, self.lda_beta)
+            gamma[d, :] = gammad
+        return gamma
+
+    def __getitem__(self, bow, eps=0.01):
+        is_corpus, corpus = utils.is_corpus(bow)
+        if is_corpus:
+          return self._apply(corpus)
+
+        gamma = self.inference([bow])[0]
+        topic_dist = gamma / sum(gamma) if sum(gamma) != 0 else []
+        return [(topicid, topicvalue) for topicid, topicvalue in enumerate(topic_dist)
+                if topicvalue >= eps]
 
     def update(self, corpus):
         save_freq = max(1, int(10000 / self.chunksize)) # save every 10k docs, roughly
@@ -216,6 +248,9 @@ class HdpModel(interfaces.TransformationABC):
 
                 if self.update_finished(start_time, chunks_processed, self.m_num_docs_processed):
                     self.update_expectations()
+                    alpha, beta = self.hdp_to_lda()
+                    self.lda_alpha = alpha
+                    self.lda_beta = beta
                     self.print_topics(20)
                     if self.outputdir:
                         self.save_topics()
@@ -228,7 +263,6 @@ class HdpModel(interfaces.TransformationABC):
                     logger.info('PROGRESS: finished document %i of %i' %
                         (self.m_num_docs_processed, self.m_D))
 
-
     def update_finished(self, start_time, chunks_processed, docs_processed):
         return (
             # chunk limit reached
@@ -240,7 +274,6 @@ class HdpModel(interfaces.TransformationABC):
             # no limits and whole corpus has been processed once
             (not self.max_chunks and not self.max_time and docs_processed >= self.m_D))
 
-
     def update_chunk(self, chunk, update=True, opt_o=True):
         # Find the unique words in this chunk...
         unique_words = dict()
@@ -281,7 +314,6 @@ class HdpModel(interfaces.TransformationABC):
 
         return (score, count)
 
-
     def doc_e_step(self, doc, ss, Elogsticks_1st, word_list,
             unique_words, doc_word_ids, doc_word_counts, var_converge) :
         """
@@ -369,7 +401,6 @@ class HdpModel(interfaces.TransformationABC):
 
         return likelihood
 
-
     def update_lambda(self, sstats, word_list, opt_o):
         self.m_status_up_to_date = False
         # rhot will be between 0 and 1, and says how much to weight
@@ -400,7 +431,6 @@ class HdpModel(interfaces.TransformationABC):
         var_phi_sum = np.flipud(self.m_varphi_ss[1:])
         self.m_var_sticks[1] = np.flipud(np.cumsum(var_phi_sum)) + self.m_gamma
 
-
     def optimal_ordering(self):
         """
         ordering the topics
@@ -411,7 +441,6 @@ class HdpModel(interfaces.TransformationABC):
         self.m_lambda_sum = self.m_lambda_sum[idx]
         self.m_Elogbeta = self.m_Elogbeta[idx, :]
 
-
     def update_expectations(self):
         """
         Since we're doing lazy updates on lambda, at any given moment
@@ -429,7 +458,6 @@ class HdpModel(interfaces.TransformationABC):
         self.m_timestamp[:] = self.m_updatect
         self.m_status_up_to_date = True
 
-
     def print_topics(self, topics=20, topn=20):
         if not self.m_status_up_to_date:
             self.update_expectations()
@@ -437,7 +465,6 @@ class HdpModel(interfaces.TransformationABC):
         hdp_formatter = HdpTopicFormatter(self.id2word, betas)
         hdp_formatter.print_topics(topics, topn)
 
-
     def save_topics(self, doc_count=None):
         """legacy method; use `self.save()` instead"""
         if not self.outputdir:
@@ -452,7 +479,6 @@ class HdpModel(interfaces.TransformationABC):
         betas = self.m_lambda + self.m_eta
         np.savetxt(fname, betas)
 
-
     def save_options(self):
         """legacy method; use `self.save()` instead"""
         if not self.outputdir:
@@ -472,7 +498,6 @@ class HdpModel(interfaces.TransformationABC):
             fout.write('eta: %s\n' % str(self.m_eta))
             fout.write('gamma: %s\n' % str(self.m_gamma))
 
-
     def hdp_to_lda(self):
         """
         Compute the LDA almost equivalent HDP.
@@ -481,7 +506,7 @@ class HdpModel(interfaces.TransformationABC):
         sticks = self.m_var_sticks[0] / (self.m_var_sticks[0] + self.m_var_sticks[1])
         alpha = np.zeros(self.m_T)
         left = 1.0
-        for i in range(0, self.m_T - 1):
+        for i in xrange(0, self.m_T - 1):
             alpha[i] = sticks[i] * left
             left = left - alpha[i]
         alpha[self.m_T - 1] = left
@@ -493,18 +518,18 @@ class HdpModel(interfaces.TransformationABC):
 
         return (alpha, beta)
 
-
     def evaluate_test_corpus(self, corpus):
         logger.info('TEST: evaluating test corpus')
-        (lda_alpha, lda_beta) = self.hdp_to_lda()
+        if self.lda_alpha is None or self.lda_beta is None:
+            self.lda_alpha, self.lda_beta = self.hdp_to_lda()
         score = 0.0
         total_words = 0
         for i, doc in enumerate(corpus):
             if len(doc) > 0:
                 doc_word_ids, doc_word_counts = zip(*doc)
-                (likelihood, gamma) = lda_e_step(doc_word_ids, doc_word_counts, lda_alpha, lda_beta)
+                likelihood, gamma = lda_e_step(doc_word_ids, doc_word_counts, self.lda_alpha, self.lda_beta)
                 theta = gamma / np.sum(gamma)
-                lda_betad = lda_beta[:, doc_word_ids]
+                lda_betad = self.lda_beta[:, doc_word_ids]
                 log_predicts = np.log(np.dot(theta, lda_betad))
                 doc_score = sum(log_predicts) / len(doc)
                 logger.info('TEST: %6d    %.5f' % (i, doc_score))
