@@ -10,7 +10,7 @@ STOPWORDS = """
 a about above across after afterwards again against all almost alone along already also although always am among amongst amoungst amount an and another any anyhow anyone anything anyway anywhere are around as at back be
 became because become becomes becoming been before beforehand behind being below beside besides between beyond bill both bottom but by call can
 cannot cant co computer con could couldnt cry de describe
-detail did do doesn done down due during
+detail did do does doesn done down due during
 each eg eight either eleven else elsewhere empty enough etc even ever every everyone everything everywhere except few fifteen
 fify fill find fire first five for former formerly forty found four from front full further get give go
 had has hasnt have he hence her here hereafter hereby herein hereupon hers herself him himself his how however hundred i ie
@@ -93,7 +93,7 @@ def preprocess_string(s, filters=DEFAULT_FILTERS):
 
 
 def preprocess_documents(docs):
-    return map(preprocess_string, docs)
+    return [preprocess_string(d) for d in docs]
 
 
 def read_file(path):
@@ -101,4 +101,4 @@ def read_file(path):
 
 
 def read_files(pattern):
-    return map(read_file, glob.glob(pattern))
+    return [read_file(fname) for fname in glob.glob(pattern)]
