@@ -3,4 +3,4 @@ This package contains implementations of pairwise similarity queries.
 """
 
 # bring classes directly into package namespace, to save some typing
-from docsim import Similarity, MatrixSimilarity, SparseMatrixSimilarity
+from .docsim import Similarity, MatrixSimilarity, SparseMatrixSimilarity
